Module secretclasses

Module secretclasses 

Structs

SecretClass
Auto-generated derived type for SecretClassSpec via CustomResource
SecretClassBackend
Each SecretClass is associated with a single [backend](https://docs.stackable.tech/home/nightly/secret-operator/secretclass#backend), which dictates the mechanism for issuing that kind of Secret.
SecretClassBackendAutoTls
The [autoTls backend](https://docs.stackable.tech/home/nightly/secret-operator/secretclass#backend-autotls) issues a TLS certificate signed by the Secret Operator. The certificate authority can be provided by the administrator, or managed automatically by the Secret Operator.
SecretClassBackendAutoTlsAdditionalTrustRoots
SecretClassBackendAutoTlsAdditionalTrustRootsConfigMap
Reference (name and namespace) to a Kubernetes ConfigMap object where additional certificates are stored. The extensions of the keys denote its contents: A key suffixed with .crt contains a stack of base64 encoded DER certificates, a key suffixed with .der contains a binary DER certificate.
SecretClassBackendAutoTlsAdditionalTrustRootsSecret
Reference (name and namespace) to a Kubernetes Secret object where additional certificates are stored. The extensions of the keys denote its contents: A key suffixed with .crt contains a stack of base64 encoded DER certificates, a key suffixed with .der contains a binary DER certificate.
SecretClassBackendAutoTlsCa
Configures the certificate authority used to issue Pod certificates.
SecretClassBackendAutoTlsCaKeyGeneration
The algorithm used to generate a key pair and required configuration settings. Currently only RSA and a key length of 2048, 3072 or 4096 bits can be configured.
SecretClassBackendAutoTlsCaKeyGenerationRsa
SecretClassBackendAutoTlsCaSecret
Reference (name and namespace) to a Kubernetes Secret object where the CA certificate and key is stored in the keys ca.crt and ca.key respectively.
SecretClassBackendExperimentalCertManager
The experimentalCertManager backend injects a TLS certificate issued by [cert-manager](https://cert-manager.io/).
SecretClassBackendExperimentalCertManagerIssuer
A reference to the cert-manager issuer that the certificates should be requested from.
SecretClassBackendExperimentalCertManagerKeyGeneration
The algorithm used to generate a key pair and required configuration settings. Currently only RSA and a key length of 2048, 3072 or 4096 bits can be configured.
SecretClassBackendExperimentalCertManagerKeyGenerationRsa
SecretClassBackendK8sSearch
The [k8sSearch backend](https://docs.stackable.tech/home/nightly/secret-operator/secretclass#backend-k8ssearch) can be used to mount Secrets across namespaces into Pods.
SecretClassBackendK8sSearchSearchNamespace
Configures the namespace searched for Secret objects.
SecretClassBackendK8sSearchSearchNamespacePod
The Secret objects are located in the same namespace as the Pod object. Should be used for Secrets that are provisioned by the application administrator.
SecretClassBackendKerberosKeytab
The [kerberosKeytab backend](https://docs.stackable.tech/home/nightly/secret-operator/secretclass#backend-kerberoskeytab) creates a Kerberos keytab file for a selected realm. The Kerberos KDC and administrator credentials must be provided by the administrator.
SecretClassBackendKerberosKeytabAdmin
Kerberos admin configuration settings.
SecretClassBackendKerberosKeytabAdminActiveDirectory
Credentials should be provisioned in a Microsoft Active Directory domain.
SecretClassBackendKerberosKeytabAdminActiveDirectoryExperimentalGenerateSamAccountName
Allows samAccountName generation for new accounts to be customized. Note that setting this field (even if empty) makes the Secret Operator take over the generation duty from the domain controller.
SecretClassBackendKerberosKeytabAdminActiveDirectoryLdapTlsCaSecret
Reference (name and namespace) to a Kubernetes Secret object containing the TLS CA (in ca.crt) that the LDAP server’s certificate should be authenticated against.
SecretClassBackendKerberosKeytabAdminActiveDirectoryPasswordCacheSecret
Reference (name and namespace) to a Kubernetes Secret object where workload passwords will be stored. This must not be accessible to end users.
SecretClassBackendKerberosKeytabAdminKeytabSecret
Reference (name and namespace) to a K8s Secret object where a keytab with administrative privileges is stored in the key keytab.
SecretClassBackendKerberosKeytabAdminMit
Credentials should be provisioned in a MIT Kerberos Admin Server.
SecretClassSpec
A SecretClass(https://docs.stackable.tech/home/nightly/secret-operator/secretclass) is a cluster-global Kubernetes resource that defines a category of secrets that the Secret Operator knows how to provision.

Enums

SecretClassBackendAutoTlsCaKeyGenerationRsaLength
SecretClassBackendExperimentalCertManagerIssuerKind
A reference to the cert-manager issuer that the certificates should be requested from.
SecretClassBackendExperimentalCertManagerKeyGenerationRsaLength