pub struct SecretClassBackendExperimentalCertManagerIssuer {
pub kind: SecretClassBackendExperimentalCertManagerIssuerKind,
pub name: String,
}Expand description
A reference to the cert-manager issuer that the certificates should be requested from.
Fields
kind: SecretClassBackendExperimentalCertManagerIssuerKindThe kind of the issuer, Issuer or ClusterIssuer.
If Issuer then it must be in the same namespace as the Pods using it.
name: StringThe name of the issuer.