pub struct TrustStoreSpec {
pub format: Option<TrustStoreFormat>,
pub secret_class_name: String,
pub target_kind: Option<TrustStoreTargetKind>,
}Expand description
A TrustStore(https://docs.stackable.tech/home/nightly/secret-operator/truststore) requests information about how to validate secrets issued by a [SecretClass](https://docs.stackable.tech/home/nightly/secret-operator/secretclass).
The requested information is written to a ConfigMap with the same name as the TrustStore.
Fields
format: Option<TrustStoreFormat>The format(https://docs.stackable.tech/home/nightly/secret-operator/secretclass#format) that the data should be converted into.
secret_class_name: StringThe name of the SecretClass that the request concerns.
target_kind: Option<TrustStoreTargetKind>Which Kubernetes kind should be used to output the requested information to.
The trust information (such as a ca.crt) can be considered public information, so we put it in a ConfigMap by default. However, some tools might require it to be placed in a Secret, so we also support that.
Can be either ConfigMap or Secret, defaults to ConfigMap.