pub struct SecretClassBackendKerberosKeytabAdminActiveDirectory {
pub experimental_generate_sam_account_name: Option<SecretClassBackendKerberosKeytabAdminActiveDirectoryExperimentalGenerateSamAccountName>,
pub ldap_server: String,
pub ldap_tls_ca_secret: SecretClassBackendKerberosKeytabAdminActiveDirectoryLdapTlsCaSecret,
pub password_cache_secret: SecretClassBackendKerberosKeytabAdminActiveDirectoryPasswordCacheSecret,
pub schema_distinguished_name: String,
pub user_distinguished_name: String,
}Expand description
Credentials should be provisioned in a Microsoft Active Directory domain.
Fields
experimental_generate_sam_account_name: Option<SecretClassBackendKerberosKeytabAdminActiveDirectoryExperimentalGenerateSamAccountName>Allows samAccountName generation for new accounts to be customized. Note that setting this field (even if empty) makes the Secret Operator take over the generation duty from the domain controller.
ldap_server: StringAn AD LDAP server, such as the AD Domain Controller. This must match the server’s FQDN, or GSSAPI authentication will fail.
ldap_tls_ca_secret: SecretClassBackendKerberosKeytabAdminActiveDirectoryLdapTlsCaSecretReference (name and namespace) to a Kubernetes Secret object containing the TLS CA (in ca.crt) that the LDAP server’s certificate should be authenticated against.
password_cache_secret: SecretClassBackendKerberosKeytabAdminActiveDirectoryPasswordCacheSecretReference (name and namespace) to a Kubernetes Secret object where workload passwords will be stored. This must not be accessible to end users.
schema_distinguished_name: StringThe root Distinguished Name (DN) for AD-managed schemas, typically CN=Schema,CN=Configuration,{domain_dn}.
user_distinguished_name: StringThe root Distinguished Name (DN) where service accounts should be provisioned, typically CN=Users,{domain_dn}.